//Bibliothek zum interagieren mit dem 4x4 Tastenfeld
#include <Keypad.h>

//Bibliotheken zum kommunizieren mit dem Display
#include <SPI.h>
#include <Wire.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>

//Auflösung des Displays mit 128 x 64 Pixel
#define SCREEN_WIDTH 128
#define SCREEN_HEIGHT 64

//kein RESET Pin angeschlossen
#define OLED_RESET -1

//Adresse des Displays (default)
#define SCREEN_ADDRESS 0x3C

//Instanz des Displays mit der Konfiguration erzeugen
Adafruit_SSD1306 display(SCREEN_WIDTH, SCREEN_HEIGHT, &Wire, OLED_RESET);

//Keypad hat 4 Zeilen & 4 Spalten
const byte COLS = 4;
const byte ROWS = 4;

//Definieren der Pins, über welche die Matrix Tastatur
//mit dem Microcontroller verbunden wurde.
const byte COL_PINS[COLS] = { 5, 4, 3, 2 };
const byte ROW_PINS[ROWS] = { 6, 7, 8, 9 };

//Da der Datentyp char nur ein Zeichen aufnehmen kann,
//verwende ich ab der Zahl 10 die Buchstaben A bis G.
const char KEYS[ROWS][COLS] = {
  { '1', '2', '3', 'A' },
  { '4', '5', '6', 'B' },
  { '7', '8', '9', 'C' },
  { '*', '0', '#', 'D' }
};

Keypad myKeypad = Keypad(makeKeymap(KEYS), ROW_PINS, COL_PINS, ROWS, COLS);

void setup() {
  //beginn der seriellen Kommunikation mit 9600 baud
  Serial.begin(9600);

  //beginn der Kommunikation mit dem Display
  //am Anfang wird zunächst das Logo von Adafruit angezeigt
  display.begin(SSD1306_SWITCHCAPVCC, SCREEN_ADDRESS);
  display.display();
}

void loop() {
  //lesen ob eine Taste gedrückt wurde
  char key = myKeypad.getKey();
  //Wenn eine Taste gedrückt wurde,
  //dann den Wert auf der seriellen Konsole
  //Ausgeben.
  if (key) {
    //Ausgeben der Taste auf der seriellen Schnittstelle
    Serial.print("Die Taste ");
    Serial.print(key);
    Serial.println(" wurde gedrueckt");

    //Ausgeben der Taste auf dem OLED-Display
    //leeren des Displays
    display.clearDisplay();
    //Schriftgröße auf 5 setzen
    display.setTextSize(5);
    //Schriftfarbe auf weiß setzen
    display.setTextColor(SSD1306_WHITE);
    //setzen des Cursors auf die Spalte 55 und die Zeile 20
    display.setCursor(55, 20);
    //schreiben des Textes an die Position vom Cursor
    display.println(key);
    //absenden der Daten an das Display,
    //diese Zeile muss immer am Ende ausgeführt werden, da sonst
    //keine Anzeige am Display erfolgt
    display.display();
  }
}